# Efficiency Unleashed: A Guide to Automating WooCommerce through CLI

### This is the script for the workshop given at WordCamp Europe
### https://europe.wordcamp.org/2024/session/efficiency-unleashed-a-guide-to-automating-woocommerce-through-cli/
### 
### You can download the last version of this script at
### https://www.jesusamieiro.com/woocommerce-cli-wceu-2024/ 
### (link available when the event starts).
### 
### After executing all these commands, you will have a store 
### where you will be able to sell fresh pasta in Spain ;) 
### 
### This script has been tested with ZSH 5.9 (x86_64-apple-darwin23.0)
### This script is not designed to be executed: 
### it is designed to copy and paste commands.
### 
### I have used:
### - WordPress 6.5.3 (en_US)
### - WooCommerce 8.9.3
### - PHP 8.0.30
### - NGINX 1.27.0
### - MySQL 8.3.0
### - WP-CLI 2.10.0
### 
### I have used 3 types of commands:
### - Starting with $, to produce an error in the shell. 
###   This is to avoid unexpected results.
### - Starting with ·, to produce an error in the shell, 
###   when some commands are together, making a shell script
###   or something similar.
### - Without any character, to copy and paste in your shell. 
### 
### Installation
### - My local installation runs on https://woocommerce.test domain. 
###   I will use this URL in the whole script.
### 
### Local paths:
### - WordPress installation: /Users/amieiro/code/wordpress/woocommerce
### - Photos for the WooCommerce products: /Users/amieiro/Google Drive/Projects/talks/20240615-WC-Europe-WP-CLI-WooCommerce/photos 
### - Scripts: /Users/amieiro/Google Drive/Projects/talks/20240615-WC-Europe-WP-CLI-WooCommerce/code
### 
### I have define some paths to use it as shell variables in the script.
### Change it as you need.

WORDPRESS_BASE_PATH="/Users/amieiro/code/wordpress/woocommerce"
PHOTOS_PATH="/Users/amieiro/Google Drive/Projects/talks/20240615-WC-Europe-WP-CLI-WooCommerce/photos"
WORDPRESS_DOMAIN="woocommerce.test"
WORDPRESS_TITLE="Italian pasta"
WORDPRESS_LOCALE="en_US" # en_US is the default locale 
WORDPRESS_ADMIN_USER="woocommerce"
WORDPRESS_ADMIN_PASSWORD="password"
WORDPRESS_ADMIN_EMAIL="hello@${WORDPRESS_DOMAIN}"
MYSQL_DATABASE="woocommerce"
MYSQL_USER="woocommerce"
MYSQL_PASSWORD="password"

##################################################################
# Install the WP-CLI
# https://make.wordpress.org/cli/handbook/guides/installing/
##################################################################
### Download the PHAR file from the official repo
$ curl -O https://raw.githubusercontent.com/wp-cli/builds/gh-pages/phar/wp-cli.phar

### Make the file executable
$ chmod +x wp-cli.phar

### Move to a folder in the path, changing the name
$ sudo mv wp-cli.phar /usr/local/bin/wp

### Test it
$ wp --info
$ wp cli info

$ wp --version
$ wp cli version

### This is the WP-CLI command structure
$ wp command subcommand options

### Two examples
$ wp cli update 
$ wp theme install storefront --version=5.9 --help
#### In the last command, we have this options:
#### - Individual parameters: storefront
#### - Asociative parameters: --version=5.9
#### - Flags: --force, --activate, --help

### You can get the help with the "help" command
$ wp help theme install storefront --version=5.9

##################################################################
# Install WordPress
##################################################################
### I have a MySQL database with this access data, previously
### defined in some shell variables:
### 
### - Database: woocommerce
### - Username: woocommerce
### - Password: password
###
### I will:
### - Create the database
### - Download WordPress
### - Create and populate wp-config.php
### - Install WordPress
### - Update the permalink structure
### - Install and activate the plugins
### - Install and activate the theme
### - Install and activate the translations
### - Delete unneeded plugins and themes
###  
#·································································
# Create the database, the user and grant privileges
### Please, use strong passwords in production
#·································································
### CREATE DATABASE woocommerce CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
### CREATE USER 'woocommerce'@'localhost' identified by 'password';
### GRANT ALL PRIVILEGES ON woocommerce.* TO woocommerce@localhost;
### FLUSH PRIVILEGES;

#·································································
# Remove previous installations
# Download WordPress
# Create and populate wp-config.php
# Install WordPress
# Update the permalink structure
#·································································
cd $WORDPRESS_BASE_PATH

### Optional, to remove all tables with `$table_prefix` from the database.
wp db clean --yes
### Remove all the files from a previous installation
rm -rf *
wp core download --locale=$WORDPRESS_LOCALE 
wp config create \
   --dbname=$MYSQL_DATABASE \
   --dbuser=$MYSQL_USER \
   --dbpass=$MYSQL_PASSWORD 

### Install WordPress
wp core install  \
   --url=$WORDPRESS_DOMAIN \
   --title=$WORDPRESS_TITLE \
   --admin_user=$WORDPRESS_ADMIN_USER \
   --admin_password=$WORDPRESS_ADMIN_PASSWORD \
   --admin_email=$WORDPRESS_ADMIN_EMAIL

### Update the permalink structure
wp rewrite structure '/%postname%/'

#·································································
# Install and activate the plugins
# Install and activate the theme
# Install and activate the translations
# Delete unneeded plugins and themes
#·································································
### Install the plugins 
wp plugin install \
   woocommerce \
   --activate

### Install the theme
wp theme install storefront \
  --activate

### Install the translations (not in this site)
$ wp language core install es_ES --activate
$ wp language plugin install --all es_ES
$ wp language theme install storefront es_ES

### Remove unused plugins and themes
wp plugin delete akismet hello
wp plugin list
wp theme delete twentytwentytwo twentytwentythree twentytwentyfour
wp theme list
### We can download WordPress without the default themes and plugins
### using the --skip-content parameter.
$ wp core download --locale=$WORDPRESS_LOCALE --skip-content

### Set the auto-updates for plugins
wp plugin auto-updates enable woocommerce
wp plugin list

### and for the themes
wp theme auto-updates enable storefront
wp theme list

##################################################################
# Useful CLI commands
### In the next lines, you are going to see some
### useful examples of WP-CLI:
### 1. Flush cache. 
### 2. Delete spam comments.
### 3. Create automated backups.
### 4. Create the .pot files for i18n.
### 5. Deactivate plugins, to detect problematic plugins 
###    and conflicts between plugins.
### 6. Update the URL when you migrate from a development 
###    environment to production.
### 7. Set the site in maintenance mode.
### 8. Update core, plugins, themes and translations automatically.
###
##################################################################
# You can see all WP-CLI commands executing
wp
#·································································
# Flush cache
#·································································
### Determine which object cache is being used.
$ wp cache type
$ wp cache flush

#·································································
# Delete spam comments
#·································································
$ wp comment generate --format=ids --count=5 | tr ' ' '\n' | xargs -I % wp comment spam %
$ wp comment delete $(wp comment list --format=ids --status=spam)

#·································································
# Create automated backups
#·································································
$ wp db export --add-drop-table
$ scp *.sql myuser@example.com:/home/backups
$ rm *.sql 
### Execute it each night in a shell script with the system cron.
###
### Later, if you need the backup
$ wp db import woocommerce-2024-06-15-4797eda.sql

#·································································
# Create the .pot files for i18n
#·································································
$ wp i18n make-pot wp-content/plugins/woocommerce wp-content/plugins/woocommerce/languages/woocommerce.pot

#·································································
# Deactivate plugins, to detect problematic plugins 
# and conflict between plugins
#·································································
$ wp plugin deactivate --all
$ wp plugin activate woocommerce

#·································································
# Update the URL when you migrate from a development environment
# to production
#·································································
$ wp search-replace "http://woocommerce.test" \
"https://www.example.com" --skip-columns=guid --dry-run

#·································································
# Set the site in maintenance mode
#·································································
$ wp maintenance-mode activate
$ wp maintenance-mode deactivate
$ wp maintenance-mode is-active
$ echo $?

### You can create an script to check the maintenance-mode
### status and deactive it if is needed
· wp maintenance-mode is-active
· if [ $? -ne 1 ];
· then
·    wp maintenance-mode deactivate
· fi

#·································································
# Update core, plugins, themes and translations
# You can run a script with these commands each night
#·································································
wp core update
wp plugin update --all
wp theme update --all
wp language core update
wp language plugin update --all
wp language theme update --all

##################################################################
# WooCommerce CLI commands
##################################################################

### See all WooCommerce CLI commands
$ wp wc 

### Allows to connect and interact with 
### extensions from WooCommerce.com marketplace.
$ wp wc com --help

### Allows to interact with High-Performance Order 
### Storage (HPOS) (previously known as Custom Order Tables).
$ wp wc cot --help

### Allows to manage WooCommerce customers, including 
### creating, updating, deleting, and retrieving customer details.
$ wp wc customer --help

### List download permissions for a specific customer..
$ wp wc customer_download list --help

### Allows to manage High-Performance Order Storage, 
### a feature for optimizing WooCommerce order data storage.
$ wp wc hpos --help

### Add, delete, or view notes related to orders, often used 
### for internal communication or customer updates.
$ wp wc order_note --help

### Manage payment gateways, enabling you to list, update and
### retrieve details.
$ wp wc payment_gateway --help

### Perform operations on products, including creation, updating, 
### deletion, and retrieval of product details.
$ wp wc product --help

### Manage product attributes, such as sizes or colors, which 
### are used to define product variations.
$ wp wc product_attribute --help

### Handle terms within product attributes, like specific 
### values of an attribute.
$ wp wc product_attribute_term --help

### Manage product categories, including adding, editing, 
### and removing categories.
$ wp wc product_cat --help

### Manage customer reviews for products, including 
### moderating and deleting reviews.
$ wp wc product_review --help

### Handle shipping classes, which are used to group 
### products with similar shipping requirements.
$ wp wc product_shipping_class --help

### Manage product tags, which help in organizing and
### finding products.
$ wp wc product_tag --help

### Handle product variations, such as different sizes 
### or colors of a product.
$ wp wc product_variation --help

### Allow to list or get details for the shipping methods.
$ wp wc shipping_method --help

### Define and manage shipping zones, which specify regions 
### for different shipping rules.
$ wp wc shipping_zone --help

### Manage locations within shipping zones.
$ wp wc shipping_zone_location --help

### Handle shipping methods specific to a shipping zone.
$ wp wc shipping_zone_method --help

### Manage discount coupons, including creation, 
### modification, and deletion of coupons.
$ wp wc shop_coupon --help

### Manage orders, including creating, updating, retrieving, 
### and deleting orders.
$ wp wc shop_order --help

### Handle order refunds, processing refunds for 
### returned or canceled orders.
$ wp wc shop_order_refund --help

### Manage tax rates and rules, including creation, updating, 
### and deletion of tax settings.
$ wp wc tax --help

### Handle tax classes, which are groups of products
### with similar tax rates.
$ wp wc tax_class --help

### Access various tools provided by WooCommerce,
### such as database tools or system status tools.
$ wp wc tool list --user=$WORDPRESS_ADMIN_USER

### Dump tracker snapshot data to screen.
### Useful with the grep command to look for some elements.
$ wp wc tracker snapshot --format=json
$ wp wc tracker snapshot --format=yaml 

### Runs all pending WooCommerce database updates.
### https://github.com/woocommerce/woocommerce/wiki/Upgrading-the-database-using-WP-CLI
$ wp wc update --help

### Manage webhooks, which allow WooCommerce to communicate 
### with external services by sending automated messages or 
### updates.
$ wp wc webhook --help

### Manage webhook deliveries, retrieving details of a specific 
### webhook delivery or list all webhook deliveries.
$ wp wc webhook_delivery --help

##################################################################
# WooCommerce settings
##################################################################

### Create default WooCommerce pages.
### Usually, these pages are created
### when we activate WooCommerce.
### - Shop
### - Cart
### - Checkout
### - My account
wp wc \
tool run install_pages \
--user=$WORDPRESS_ADMIN_USER

### But we need to create he "Terms and conditions"
### page and add as the page of "Terms and conditions" 
### to WooCommerce
TC_PAGE_ID=$(wp post create \
--post_title="Terms and conditions" \
--post_content="Lorem ipsum dolor sit amet" \
--post_type=page \
--post_author=$WORDPRESS_ADMIN_USER \
--post_status=publish \
--porcelain)

### This option is stored on the "_options" table.
wp option set \
woocommerce_terms_page_id \
$TC_PAGE_ID

### Change the homepage to the "Shop" page
wp option update show_on_front 'page'

SHOP_PAGE_ID=$(wp post list \
--post_type=page \
--name=shop \
--format=ids)

wp option update page_on_front $SHOP_PAGE_ID

### Hide the guided setup
wp option set \
   woocommerce_onboarding_profile \
   '{
      "skipped": true
   }' \
   --format=json

#·································································
# General Settings
# WooCommerce -> Settings -> General
# https://woocommerce.com/document/configuring-woocommerce-settings/general/
#·································································
# Store Address.
### The street address for your business location.
wp option set woocommerce_store_address \
   "Muíños de arriba"

### An additional, optional address line for your business location.
wp option set woocommerce_store_address_2 \
   "1, baixo"

### The city in which your business is located.
wp option set woocommerce_store_city \
   "Mondoñedo"

### The country and state or province, if any, in which your business is located.
### https://github.com/woocommerce/woocommerce/blob/trunk/plugins/woocommerce/i18n/states.php
wp option set woocommerce_default_country \
   "ES:LU"

### The postal code, if any, in which your business is located.
wp option set woocommerce_store_postcode \
   "27740"

# General options.
### This option lets you limit which countries you are willing to sell to.
wp option set \
   woocommerce_allowed_countries \
   "specific"

### Sell to specific countries. 
### Sell only to Spain.
wp option set \
   woocommerce_specific_allowed_countries \
   '["ES"]' --format=json

### If I want to sell to Spain and Portugal
· wp option set \
·   woocommerce_specific_allowed_countries \
·   '["ES", "PT"]' --format=json

### Shipping location(s).
### Choose which countries you want to ship to, 
### or choose to ship to all locations you sell to
### (default value).
wp option set \
   woocommerce_ship_to_countries ""

### This option determines a customers default location. 
### The MaxMind GeoLite Database will be periodically 
### downloaded to your wp-content directory if using geolocation.
wp option set \
   woocommerce_default_customer_address "base"

### Enable tax rates and calculations.
wp option set \
   woocommerce_calc_taxes "yes"

### Enable the use of coupon codes.
### (default value).
wp option set \
   woocommerce_enable_coupons "yes"

### Calculate coupon discounts sequentially.
### When applying multiple coupons, apply the first coupon 
### to the full price and the second coupon to the 
### discounted price and so on.
wp option set \
   woocommerce_calc_discounts_sequentially "yes"

# Currency options.
### Currency.
### This controls what currency prices are listed at in 
### the catalog and which currency gateways will take payments in.
wp option set woocommerce_currency "EUR"

### Currency position.
### This controls the position of the currency symbol.
wp option set woocommerce_currency_pos "right_space"

### Thousand separator.
### This sets the thousand separator of displayed prices.
wp option set woocommerce_price_thousand_sep "."

### Decimal separator.
### This sets the decimal separator of displayed prices.
wp option set woocommerce_price_decimal_sep ","

### Number of decimals.
### This sets the number of decimal points shown in displayed prices.
wp option set woocommerce_price_num_decimals 2

#·································································
# Taxes
# WooCommerce -> Settings -> Tax
# https://woocommerce.com/document/setting-up-taxes-in-woocommerce/
# The tax settings tab won’t be visible until taxes 
# are enabled in the general settings.
#·································································
### WooCommerce -> Settings -> Tax -> Tax options
### Prices entered with tax.
wp option set \
   woocommerce_prices_include_tax "yes"

### Calculate tax based on.
### This option determines which address is used to calculate tax.
wp option set \
   woocommerce_tax_based_on "billing"

### Shipping tax class.
### standard (default value).
wp option set \
   woocommerce_shipping_tax_class ""

### Rounding.
### Round tax at subtotal level, instead of rounding per line.
wp option set \
   woocommerce_tax_round_at_subtotal "yes"

### Display prices in the shop including tax.
wp option set \
   woocommerce_tax_display_shop "incl"

### Display prices during cart and checkout including tax.
wp option set \
   woocommerce_tax_display_cart "incl"

### Define text to show after your product prices.
wp option set \
   woocommerce_price_display_suffix "inc. VAT"

### Display tax totals.
wp option set \
   woocommerce_tax_total_display "itemized"

### WooCommerce -> Settings -> Tax -> Standard rates
### Create a new tax for Spain.
### https://github.com/woocommerce/woocommerce/blob/trunk/plugins/woocommerce/i18n/states.php
wp wc tax create --country=ES --rate=21 \
   --name="VAT 21%" --priority=1 \
   --class=standard \
   --compound=0 --shipping=0 --user=$WORDPRESS_ADMIN_USER

#·································································
# Shipping
# WooCommerce -> Settings -> Shipping
#·································································
#### WooCommerce -> Settings -> Shipping -> Local pickup
### Local pickup will appear as an option on the block based checkout.
wp option set --format=json \
   woocommerce_pickup_location_settings \
   '{"enabled":"yes",
      "title":"Local Pickup",
      "tax_status":"taxable",
      "cost":"0"}'

### Two pickup locations: the restaurant and the factory.
wp option set --format=json \
   pickup_location_pickup_locations \
   '[
      {
        "name": "Restaurant",
        "address": {
            "address_1": "Muíños de arriba 1, baixo",
            "city": "Mondoñedo",
            "state": "LU",
            "postcode": "27740",
            "country": "ES"
        },
        "details": "Opening hours from 11:30 to 22:00 hours.",
        "enabled": true
      }, 
      {
        "name": "Factory",
        "address": {
            "address_1": "Muíños de arriba 25, baixo",
            "city": "Mondoñedo",
            "state": "LU",
            "postcode": "27740",
            "country": "ES"
        },
        "details": "Opening hours from 08:00 to 12:00 hours.",
        "enabled": true}
   ]'

# WooCommerce -> Settings -> Shipping -> Shipping zones
### Create the shipping zone.
### A shipping zone is a geographic region where a certain 
### set of shipping methods and rates apply.

### Create the Spain shipping zone.
SPAIN_SHIPPING_ZONE_ID="$(wp wc \
  shipping_zone create \
  --name="Spain" \
  --user=$WORDPRESS_ADMIN_USER \
  --porcelain)"

### Create the shipping zone method (flat_rate) for
### the previous shipping zone.
SPAIN_SHIPPING_ZONE_METHOD_ID="$(wp wc \
  shipping_zone_method create \
  $SPAIN_SHIPPING_ZONE_ID \
  --method_id=flat_rate \
  --enabled=true \
  --user=$WORDPRESS_ADMIN_USER \
  --porcelain)"

### Set the options for the prvevious shipping zone method.
wp option set --format=json \
   woocommerce_flat_rate_${SPAIN_SHIPPING_ZONE_METHOD_ID}_settings \
   '{
    "title": "MRW",
    "tax_status": "none",
    "cost": "4,99"}'

### Assign the previous shipping zone to Spain (country).
wp db query \
  "INSERT INTO \
  wp_woocommerce_shipping_zone_locations \
  (zone_id, location_code, location_type) \
  VALUES ('$SPAIN_SHIPPING_ZONE_ID', 'ES', 'country')"

#·································································
# Payment methods
# WooCommerce -> Settings -> Payment
#·································································
### Enable bank transfer.
### https://woocommerce.com/document/bacs/
wp option set --format=json \
   woocommerce_bacs_settings \
   '{
      "enabled":"yes",
      "title": "Direct bank transfer",
      "description": "You selected direct bank transfer. Make your payment directly into our bank account. Please use your Order ID as the payment reference. Your order will not be shipped until the funds have cleared in our account.",
      "instructions": ""
   }'

### Create two bank accounts.
wp option set --format=json \
   woocommerce_bacs_accounts \
   '[
      {
         "account_name": "BBVA account",
         "account_number": "21000418450200051332",
         "sort_code": "",
         "bank_name": "BBVA",
         "iban": "ES9121000418450200051332",
         "bic": "BBVAESMM"
      },
      {
         "account_name": "Santander account",
         "account_number": "00491500051234567892",
         "sort_code": "",
         "bank_name": "Santander",
         "iban": "ES6000491500051234567892",
         "bic": "BSCHESMMXXX"
      }    
   ]'

### Enable cash on delivery.
### https://woocommerce.com/document/cash-on-delivery/
wp option set --format=json \
   woocommerce_cod_settings \
   '{
      "enabled":"yes",
      "title":"Cash on delivery",
      "description":"Pay with cash upon delivery.",
      "instructions":"Pay with cash upon delivery.",
      "enable_for_virtual":"no",
      "enable_for_methods": [
            "flat_rate:1"
    ]
   }'
#·································································
# Register and access
# WooCommerce -> Settings -> Accounts & Privacy
# https://woocommerce.com/document/configuring-woocommerce-settings/accounts-and-privacy/
#·································································

# Guest checkout.
### Allow customers to place orders without an account.
wp option set \
   woocommerce_enable_guest_checkout "yes"

### Allow customers to log into an existing account during checkout.
wp option set \
   woocommerce_enable_checkout_login_reminder "yes"

# Account creation.
### Allow customers to create an account during checkout.
wp option set \
   woocommerce_enable_signup_and_login_from_checkout "yes"

### Allow customers to create an account on the "My account" page.
wp option set \
   woocommerce_enable_myaccount_registration "yes"

### When creating an account, automatically generate an account.
### username for the customer based on their name, surname or email
### (default value).
wp option set \
   woocommerce_registration_generate_username "yes"

### When creating an account, send the new user a link 
### to set their password.
### (default value).
wp option set \
   woocommerce_registration_generate_password "yes"

# Account erasure requests.
### Remove personal data from orders on request
### (default value).
wp option set \
   woocommerce_erasure_request_removes_order_data "no"

###  Remove access to downloads on request
### (default value).
wp option set \
   woocommerce_erasure_request_removes_download_data "no"

# Personal data removal.
### Allow personal data to be removed in bulk from orders
### (default value).
wp option set \
   woocommerce_allow_bulk_remove_personal_data "no"

# Privacy policy.
### Registration privacy policy.
wp option update \
   woocommerce_registration_privacy_policy_text \
   "We use your personal data to enhance your experience on \
this website, manage your account access, and for other \
purposes outlined in our [privacy_policy]."

### Checkout privacy policy.
wp option update \
   woocommerce_checkout_privacy_policy_text \
   "We use your personal data to process your order, enhance \
your website experience, and for other purposes detailed \
in our [privacy_policy]."

# Personal data retention.
### Retain inactive accounts.
wp option set \
woocommerce_delete_inactive_accounts \
'{"number": 24, "unit": "months"}' --format=json

### Retain pending orders.
wp option set \
woocommerce_trash_pending_orders \
'{"number": 30, "unit": "days"}' --format=json

### Retain failed orders.
wp option set \
woocommerce_trash_failed_orders \
'{"number": 15, "unit": "days"}' --format=json

### Retain cancelled orders.
wp option set \
woocommerce_trash_cancelled_orders \
'{"number": 2, "unit": "weeks"}' --format=json

### Retain completed orders.
wp option set \
woocommerce_anonymize_completed_orders \
'{"number": 5, "unit": "years"}' --format=json

#·································································
# Products
# WooCommerce -> Products
# https://woocommerce.com/document/configuring-woocommerce-settings/products/
#·································································
# WooCommerce -> Products -> General
### Set kg as weight unit
wp option set \
   woocommerce_weight_unit \
   "kg"

### Set cm as dimension unit
wp option set \
   woocommerce_dimension_unit \
   "cm"

# WooCommerce -> Products -> Inventory
### Disable the stock management
wp option set \
   woocommerce_manage_stock \
   "no"

##################################################################
# Add products
##################################################################

### Create the catogory for "Fresh stuffed pasta"
FRESH_STUFFED_PASTA_CAT_ID=" \
 $(wp wc product_cat \
 create \
 --name="Fresh Stuffed Pasta" \
 --porcelain \
 --user=$WORDPRESS_ADMIN_USER )"

### Create the catogory for "Fresh unstuffed pasta"
FRESH_UNSTUFFED_PASTA_CAT_ID=" \
 $(wp wc product_cat \
 create \
 --name="Fresh Unstuffed Pasta" \
 --porcelain \
 --user=$WORDPRESS_ADMIN_USER )"

### Image path
RAVIOLI_IMAGE_PATH="${PHOTOS_PATH}/ravioli-caprese.webp"

### Import the image to the media library
RAVIOLI_IMAGE_ID="\
   $(wp media import $RAVIOLI_IMAGE_PATH \
   --alt="Ravioli caprese" \
   --user=$WORDPRESS_ADMIN_USER \
   --porcelain)"

### Create the product
wp wc product create \
   --name="Ravioli caprese" \
   --description='What if we told you that all the flavor of caprese salad can become the filling of a tasty crescent-shaped ravioli? In these special ravioli caprese, all the savory and sweet taste of sun-dried tomatoes, the fragrance of basil, the creaminess of ricotta and the stringy mozzarella cheese are concentrated. Texture and taste create the perfect mix to make this ravioli truly one of a kind!' \
   --type="simple" \
   --regular_price="19.99" \
   --sku="rav-cap-001" \
   --weight=1 \
   --categories="[ { \"id\" : $FRESH_STUFFED_PASTA_CAT_ID } ]" \
   --images="[ { \"id\" : $RAVIOLI_IMAGE_ID } ]" \
   --user=$WORDPRESS_ADMIN_USER

##################################################################
# Scripts
### Remember to give execution permissions to the scripts: 
### - chmod +x script_name.sh
##################################################################

##################################################################
# Import products from a CSV file
##################################################################

# See import_sample_data.sh script

##################################################################
# Create fake customers and orders
##################################################################

# See create_fake_orders.sh script

##################################################################
# Export pending orders, to be used in another place
##################################################################

# See export_pending_orders.sh script

##################################################################
# Customer list (for mailing purposes)
##################################################################

# See create_customer_list.sh script
